@@ -28,7 +28,13 @@
 #include "fqterm_ssh_auth.h"
 #include "fqterm_ssh_channel.h"
 #include "fqterm_trace.h"
+#include "fqterm_path.h"
+#include "ssh_known_hosts.h"
+#include "ccan_base64.h"
 #include <QString>
+#include <cstdlib>
+#include <cstring>
+
 namespace FQTerm {
 
 #define V1STR	"SSH-1.5-FQTermSSH\n"
@@ -144,6 +150,62 @@ void FQTermSSHSocket::kexOK()
 		conn_info.ssh_proto_info.c2s_mac = packet_sender_->mac->name;
 	if (packet_receiver_->mac)
 		conn_info.ssh_proto_info.s2c_mac = packet_receiver_->mac->name;
+
+	if (ssh_version_ == 2) {
+		int nhosts;
+		struct ssh_host *hosts;
+		const char *hosts_file;
+#ifdef WIN32
+		QString known_hosts = getPath(USER_CONFIG) + "known_hosts";
+		hosts_file = strdup(known_hosts.toLatin1().constData());
+#else
+		hosts_file = ssh_hosts_filename();
+#endif
+		hosts = parse_hosts_file(hosts_file, &nhosts);
+		int idx = find_ssh_host(hosts, nhosts, conn_info.hostname, conn_info.port);
+		FQTermSSH2Kex *kex = dynamic_cast<FQTermSSH2Kex *> (key_exchanger_);
+		bool isok;
+		if (idx >=0) {
+		       if (key_matches(&hosts[idx], kex->K_S(), kex->K_S_len())) {
+			       conn_info.ssh_proto_info.key_matches = 1;
+		       } else {
+			       conn_info.ssh_proto_info.key_matches = 0;
+			       emit warnInsecure("Host key mismatch!", &isok);
+			       if (!isok)
+				       handleError("Uesr closed connection due to key mismatch.");
+		       }
+		} else {
+			conn_info.ssh_proto_info.key_matches = 0;
+			unsigned char hash[32];
+			char hash_b64[64];
+			kex->hostKeyHash(hash);
+			base64_encode(hash_b64, sizeof(hash_b64), (const char*)hash, 32);
+			hash_b64[base64_encoded_length(32)-1] = 0; /* final byte is '=' */
+
+			const char *tab = "0123456789ABCDEF";
+			QString msg = "Unknown host, trust the host key?\nSHA256: ";
+			for (int i = 0; i < 32; i++) {
+				char d[4];
+				d[0] = tab[hash[i]>>4];
+				d[1] = tab[hash[i]&0xf];
+				d[2] = (i==31)?'\n':':';
+				d[3] = 0;
+				msg.append(d);
+			}
+			msg.append(QString("base64: %1").arg(hash_b64));
+			emit warnInsecure(msg, &isok);
+			if (!isok)
+				handleError("Uesr closed connection due to an unknown host.");
+			else
+				/* FIXME: port != 22? */
+				append_hostkey(hosts_file, conn_info.hostname, kex->K_S(), kex->K_S_len());
+		}
+#ifdef WIN32
+		free(hosts_file);
+#endif
+		free(hosts);
+	}
+
 	key_exchanger_->hostKeyHash(conn_info.ssh_proto_info.hash);
 	authentication_->initAuth(packet_receiver_, packet_sender_);
 }
