@@ -1,7 +1,15 @@
 #include "ssh_diffie-hellman.h"
 #include "ssh_session.h"
 #include "ssh_crypto_common.h"
+#include "curve25519/crypto_scalarmult.h"
 #include <stdlib.h>
+#include <openssl/rand.h>
+
+static const char DH_G16_SHA512[] = "diffie-hellman-group16-sha512";
+static const char DH_G14_SHA256[] = "diffie-hellman-group14-sha256";
+static const char DH_G14_SHA1[] = "diffie-hellman-group14-sha1";
+static const char DH_G1_SHA1[] = "diffie-hellman-group1-sha1";
+static const char DH_CURVE25519_SHA256[] = "curve25519-sha256@libssh.org";
 
 static const int g = 2;
 
@@ -109,11 +117,13 @@ static const unsigned char prime_group16[] = {
 void
 ssh_dh_free(SSH_DH *dh)
 {
-	BN_free(dh->g);
-	BN_free(dh->p);
+	if (dh->name != DH_CURVE25519_SHA256) {
+		BN_free(dh->priv.dh.g);
+		BN_free(dh->priv.dh.p);
+		BN_clear_free(dh->priv.dh.bn_x);
+		BN_CTX_free(dh->priv.dh.ctx);
+	}
 	ssh_md_ctx_free(dh->digest.mdctx);
-	BN_clear_free(dh->bn_x);
-	BN_CTX_free(dh->ctx);
 	free(dh->mpint_e);
 	free(dh->secret);
 	free(dh);
@@ -121,11 +131,13 @@ ssh_dh_free(SSH_DH *dh)
 
 static void dh_compute(SSH_DH *dh)
 {
-	dh->bn_x = BN_new();
-	BN_pseudo_rand_range(dh->bn_x, dh->p);
+	dh->priv.dh.bn_x = BN_new();
+
+	/* FIXME: check return value and throw error */
+	BN_rand_range(dh->priv.dh.bn_x, dh->priv.dh.p);
 
 	BIGNUM *bn_e = BN_new();
-	BN_mod_exp(bn_e, dh->g, dh->bn_x, dh->p, dh->ctx);
+	BN_mod_exp(bn_e, dh->priv.dh.g, dh->priv.dh.bn_x, dh->priv.dh.p, dh->priv.dh.ctx);
 	dh->e_len = BN_bn2mpi(bn_e, NULL);
 	dh->mpint_e = (unsigned char*)malloc(dh->e_len);
 	BN_bn2mpi(bn_e, dh->mpint_e);
@@ -135,9 +147,9 @@ static void dh_compute(SSH_DH *dh)
 static SSH_DH *create_dh()
 {
 	SSH_DH *dh = (SSH_DH*)malloc(sizeof(SSH_DH));
-	dh->ctx = BN_CTX_new();
-	dh->g = BN_new();
-	dh->p = BN_new();
+	dh->priv.dh.ctx = BN_CTX_new();
+	dh->priv.dh.g = BN_new();
+	dh->priv.dh.p = BN_new();
 	return dh;
 }
 
@@ -145,13 +157,14 @@ static SSH_DH *
 ssh_dh_group1_sha1(void)
 {
 	SSH_DH *dh = create_dh();
+	dh->name = DH_G1_SHA1;
 	dh->digest = (evp_md_t) {
 		.mdctx = ssh_md_ctx_new(),
 		.md = EVP_sha1(),
 		.hashlen = SHA_DIGEST_LENGTH
 	};
-	BN_set_word(dh->g, g);
-	BN_bin2bn(prime_group1, 128, dh->p);
+	BN_set_word(dh->priv.dh.g, g);
+	BN_bin2bn(prime_group1, 128, dh->priv.dh.p);
 	dh_compute(dh);
 	return dh;
 }
@@ -160,13 +173,14 @@ static SSH_DH *
 ssh_dh_group14_sha1(void)
 {
 	SSH_DH *dh = create_dh();
+	dh->name = DH_G14_SHA1;
 	dh->digest = (evp_md_t) {
 		.mdctx = ssh_md_ctx_new(),
 		.md = EVP_sha1(),
 		.hashlen = SHA_DIGEST_LENGTH
 	};
-	BN_set_word(dh->g, g);
-	BN_bin2bn(prime_group14, 256, dh->p);
+	BN_set_word(dh->priv.dh.g, g);
+	BN_bin2bn(prime_group14, 256, dh->priv.dh.p);
 	dh_compute(dh);
 	return dh;
 }
@@ -175,13 +189,14 @@ static SSH_DH *
 ssh_dh_group14_sha256(void)
 {
 	SSH_DH *dh = create_dh();
+	dh->name = DH_G14_SHA256;
 	dh->digest = (evp_md_t) {
 		.mdctx = ssh_md_ctx_new(),
 		.md = EVP_sha256(),
 		.hashlen = SHA256_DIGEST_LENGTH
 	};
-	BN_set_word(dh->g, g);
-	BN_bin2bn(prime_group14, 256, dh->p);
+	BN_set_word(dh->priv.dh.g, g);
+	BN_bin2bn(prime_group14, 256, dh->priv.dh.p);
 	dh_compute(dh);
 	return dh;
 }
@@ -190,17 +205,50 @@ static SSH_DH *
 ssh_dh_group16_sha512(void)
 {
 	SSH_DH *dh = create_dh();
+	dh->name = DH_G16_SHA512;
 	dh->digest = (evp_md_t) {
 		.mdctx = ssh_md_ctx_new(),
 		.md = EVP_sha512(),
 		.hashlen = SHA512_DIGEST_LENGTH
 	};
-	BN_set_word(dh->g, g);
-	BN_bin2bn(prime_group16, 512, dh->p);
+	BN_set_word(dh->priv.dh.g, g);
+	BN_bin2bn(prime_group16, 512, dh->priv.dh.p);
 	dh_compute(dh);
 	return dh;
 }
 
+static void ecdh_compute(SSH_DH *dh)
+{
+	int i;
+
+	/* FIXME: check return value and throw error */
+	RAND_bytes(dh->priv.privkey, 32);
+
+	dh->priv.privkey[0] &= 248;
+	dh->priv.privkey[31] &= 127;
+	dh->priv.privkey[31] |= 64;
+
+	dh->e_len = 36;
+	dh->mpint_e = (unsigned char*)malloc(36);
+	dh->mpint_e[0] = dh->mpint_e[1] = dh->mpint_e[2] = 0;
+	dh->mpint_e[3] = 32;
+	crypto_scalarmult_base(dh->mpint_e + 4, dh->priv.privkey);
+}
+
+static SSH_DH *
+ssh_dh_curve25519_sha256(void)
+{
+	SSH_DH *dh = (SSH_DH*)malloc(sizeof(SSH_DH));
+	dh->name = DH_CURVE25519_SHA256;
+	dh->digest = (evp_md_t) {
+		.mdctx = ssh_md_ctx_new(),
+		.md = EVP_sha256(),
+		.hashlen = SHA256_DIGEST_LENGTH
+	};
+	ecdh_compute(dh);
+	return dh;
+}
+
 void
 ssh_dh_hash(SSH_DH *dh, const unsigned char *in, unsigned char *out, size_t n)
 {
@@ -209,16 +257,37 @@ ssh_dh_hash(SSH_DH *dh, const unsigned char *in, unsigned char *out, size_t n)
 	EVP_DigestFinal_ex(dh->digest.mdctx, out, NULL);
 }
 
+static int ecdh_compute_secret(SSH_DH *dh, const unsigned char *f_bin, int f_len)
+{
+	unsigned char s[32];
+	int i, j;
+
+	if (f_len != 32)
+		return -1;
+	crypto_scalarmult(s, dh->priv.privkey, f_bin);
+	BIGNUM *bn_k = BN_new();
+	BN_bin2bn(s, 32, bn_k);
+	dh->secret_len = BN_bn2mpi(bn_k, NULL);
+	dh->secret = (unsigned char*)malloc(dh->secret_len);
+	BN_bn2mpi(bn_k, dh->secret);
+	BN_clear_free(bn_k);
+	return 0;
+}
+
 int ssh_dh_compute_secret(SSH_DH *dh, const unsigned char *f_bin, int f_len)
 {
+	if (dh->name == DH_CURVE25519_SHA256)
+		return ecdh_compute_secret(dh, f_bin, f_len);
+
 	BIGNUM *bn_f = BN_new();
 	if (bn_f == NULL || BN_bin2bn(f_bin, f_len, bn_f) == NULL)
 		return -1;
 	BIGNUM *bn_k = BN_new();
-	BN_mod_exp(bn_k, bn_f, dh->bn_x, dh->p, dh->ctx);
+	BN_mod_exp(bn_k, bn_f, dh->priv.dh.bn_x, dh->priv.dh.p, dh->priv.dh.ctx);
 	dh->secret_len = BN_bn2mpi(bn_k, NULL);
 	dh->secret = (unsigned char*)malloc(dh->secret_len);
 	BN_bn2mpi(bn_k, dh->secret);
+	BN_clear_free(bn_k);
 	return 0;
 }
 
@@ -229,10 +298,11 @@ struct
 	const char *name;
 	NEW_DH f;
 } all_dh[] = {
-	{ "diffie-hellman-group16-sha512", ssh_dh_group16_sha512 },
-	{ "diffie-hellman-group14-sha256", ssh_dh_group14_sha256 },
-	{ "diffie-hellman-group14-sha1", ssh_dh_group14_sha1 },
-	{ "diffie-hellman-group1-sha1", ssh_dh_group1_sha1 },
+	{ DH_CURVE25519_SHA256, ssh_dh_curve25519_sha256 },
+	{ DH_G16_SHA512, ssh_dh_group16_sha512 },
+	{ DH_G14_SHA256, ssh_dh_group14_sha256 },
+	{ DH_G14_SHA1, ssh_dh_group14_sha1 },
+	{ DH_G1_SHA1, ssh_dh_group1_sha1 },
 	{ NULL, NULL }
 };
 
@@ -247,6 +317,7 @@ search_dh(const char *s)
 }
 
 const char all_dh_list[] =
+	"curve25519-sha256@libssh.org,"
 	"diffie-hellman-group16-sha512,diffie-hellman-group14-sha256,"
 	"diffie-hellman-group14-sha1,diffie-hellman-group1-sha1";
 
